@@ -17,28 +17,7 @@ def get_initial_caller_dir() -> str:
     """
     caller = get_initial_caller()
     return os.path.dirname(caller) if caller else None
-def get_initial_caller_dir(_INITIAL_CALLER_DIR=None) -> str:
-    """
-    Return the directory of the script that FIRST started execution.
-    Works even when this function is called from imported modules.
-    """
 
-
-    # Cache it after first calculation
-    if _INITIAL_CALLER_DIR is not None:
-        return _INITIAL_CALLER_DIR
-
-    main_mod = sys.modules.get('__main__')
-
-    # If Python was run in an interactive environment
-    if not main_mod or not hasattr(main_mod, '__file__'):
-        _INITIAL_CALLER_DIR = os.getcwd()
-        return _INITIAL_CALLER_DIR
-
-    # RESOLVE the true initial script location
-    initial_file = os.path.realpath(main_mod.__file__)
-    _INITIAL_CALLER_DIR = os.path.dirname(initial_file)
-    return _INITIAL_CALLER_DIR
 def get_caller(i: Optional[int] = None) -> str:
     """
     Return the filename of the calling frame.
