@@ -72,7 +72,7 @@ def dynamic_import(module_path: str, namespace: dict, all_imports = None):
 
 def get_monorepo_root(directory=None,files=None):
     directory = directory or get_initial_caller_dir()
-    print(directory)
+    
     py_files = get_all_py_file_paths(directory,add=True)
     sysroots = get_all_py_sysroots(directory=directory,files=py_files)
     monorepo_root = get_common_root(sysroots)
@@ -82,10 +82,11 @@ def switch_to_monorepo_root(directory=None,files=None):
     if str(monorepo_root) not in sys.path:
         sys.path.insert(0, str(monorepo_root))
     return str(monorepo_root)
-def get_all_imports(directory=None,sysroot=None):
+def get_all_imports(directory=None,sysroot=None,globs=None):
+    globs=globs or globals()
     directory = directory or get_initial_caller_dir()
     files = get_py_files(directory=directory)
     sysroot = sysroot or switch_to_monorepo_root(directory=directory)
     for glo in files:
         imp = get_import_with_sysroot(glo, sysroot)
-        dynamic_import(imp, globals())
+        dynamic_import(imp, globs)
