@@ -225,27 +225,29 @@ def create_base_dir(directory=None, child=None):
 
 
 def get_file_parts(path):
-    
-    basename = get_safe_basename(path)
-    filename, ext = get_safe_splitext(basename=basename)
+    if path:
+        path= str(path) 
+        basename = get_safe_basename(path)
+        filename, ext = get_safe_splitext(basename=basename)
 
-    dirname = get_safe_dirname(path)
-    dirbase = get_safe_basename(dirname)
-    
-    parent_dirname = get_safe_dirname(dirname)
-    parent_dirbase = get_safe_basename(parent_dirname)
-    
-    super_dirname = get_safe_dirname(parent_dirname)
-    super_dirbase = get_safe_basename(super_dirname)
+        dirname = get_safe_dirname(path)
+        dirbase = get_safe_basename(dirname)
+        
+        parent_dirname = get_safe_dirname(dirname)
+        parent_dirbase = get_safe_basename(parent_dirname)
+        
+        super_dirname = get_safe_dirname(parent_dirname)
+        super_dirbase = get_safe_basename(super_dirname)
 
-    return {"dirname": dirname,
-            "basename": basename,
-            "filename": filename,
-            "ext": ext,
-            "dirbase":dirbase,
-            "parent_dirname":parent_dirname,
-            "parent_dirbase":parent_dirbase,
-            "super_dirname":super_dirname,
-            "super_dirbase":super_dirbase
-            }
+        return {"file_path":path,
+                "dirname": dirname,
+                "basename": basename,
+                "filename": filename,
+                "ext": ext,
+                "dirbase":dirbase,
+                "parent_dirname":parent_dirname,
+                "parent_dirbase":parent_dirbase,
+                "super_dirname":super_dirname,
+                "super_dirbase":super_dirbase
+                }
 
